# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------
# pylint: skip-file
# flake8: noqa
from msrest.serialization import Model


class TransferKey(Model):
    """
    :param transfer_key:
    :type transfer_key: str
    """

    _attribute_map = {
        'transfer_key': {'key': 'transfer_key', 'type': 'SecurityDomainJsonWebKey'},
    }

    def __init__(self, *, transfer_key=None, **kwargs) -> None:
        super(TransferKey, self).__init__(**kwargs)
        self.transfer_key = transfer_key
